@@ -1,6 +1,7 @@
 import asyncio
 
 from ..channels.sender import ValarChannelSender
+import traceback
 
 
 async def execute_channel(method, sender: ValarChannelSender):
@@ -10,5 +11,10 @@ async def execute_channel(method, sender: ValarChannelSender):
 
 def __execute__(method, sender: ValarChannelSender):
     sender.start()
-    method(sender)
-    sender.stop()
+    try:
+        response = method(sender)
+        sender.done(response)
+        sender.stop()
+    except Exception as e:
+        traceback.print_exc()
+        sender.error(str(e))
