@@ -47,6 +47,14 @@ class ValarMinio:
         )
         return BytesIO(ret.read())
 
+    def read_path(self, path) -> BytesIO:
+        bucket_name, object_name = path.split('/')
+        ret: BaseHTTPResponse = self.client.get_object(
+            bucket_name=bucket_name,
+            object_name=object_name
+        )
+        return BytesIO(ret.read())
+
     def __generate_policy__(self):
         return json.dumps({
             "Version": "2012-10-17",
