@@ -1,3 +1,7 @@
+import warnings
+
+from typing_extensions import deprecated
+
 from ..dao.abstract import AbstractDao
 from ..dao.mon_dao import MonDao
 from ..dao.orm_dao import OrmDao
@@ -14,11 +18,17 @@ class Dao(AbstractDao):
         self.fields = self.dao.fields
         self.manager = self.dao.manager
 
-    def save_many(self, array: list):
-        self.dao.save_many(array)
+    def insert_one(self, item):
+        return self.dao.insert_one(item)
 
-    def save_one(self, item, with_id=False):
-        return self.dao.save_one(item, with_id)
+    def update_one(self, item):
+        return self.dao.update_one(item)
+
+    def save_many(self, array: list):
+        return self.dao.save_many(array)
+
+    def save_one(self, item):
+        return self.dao.save_one(item)
 
     def delete_one(self, _id):
         return self.dao.delete_one(_id)
