@@ -46,7 +46,15 @@ class AbstractDao(ABC):
         return self.fields[prop]
 
     @abstractmethod
-    def save_one(self, item, with_id=False):
+    def save_one(self, item):
+        pass
+
+    @abstractmethod
+    def insert_one(self, item):
+        pass
+
+    @abstractmethod
+    def update_one(self, item):
         pass
 
     @abstractmethod
