@@ -27,11 +27,8 @@ meta_field_value_defaults = {
         },
         "core": {
             "name": {
-                'span': 16
+                'span': 24
             },
-            "enable": {
-                "span": 8
-            }
         }
     },
     'valar.MetaFieldDomain': {
@@ -104,7 +101,6 @@ meta_field_value_defaults = {
             },
             "tool": {
                 'column_width': 100,
-                'span': 24,
                 'tool': 'tree',
                 'refer': {
                     'entity': 'valar.MetaFieldTool',
@@ -119,11 +115,13 @@ meta_field_value_defaults = {
             },
             "refer": {
                 'allow_edit': False,
-                'column_width': 80
+                'column_width': 80,
+                "hide_on_form": True
             },
             "format": {
                 'allow_edit': False,
-                'column_width': 80
+                'column_width': 80,
+                "hide_on_form": True
             },
             'header_color': {
                 'tool': 'color',
