@@ -1,7 +1,6 @@
 import copy
 
 from deepmerge import always_merger
-from django.conf import settings
 
 from ..dao.defaults.field_keys_default import meta_field_key_defaults
 from ..dao.defaults.field_values_default import meta_field_value_defaults
@@ -11,7 +10,6 @@ from ..dao.frame import meta_field_tool_mapping
 from ..dao.mon_dao import MonDao
 from ..dao.orm_dao import OrmDao
 from ..dao.orm_field import column_width
-from ..models.frame import MetaFieldDomain
 from ..models.meta import Meta, MetaView
 
 
@@ -56,18 +54,15 @@ class ValarMeta:
         name, entity = meta['name'], meta['entity']
         fields = self.view.metafield_set.all().order_by('-sort')
         _fields = {}
-        _minio = settings.MINIO_ROOT if hasattr(settings, 'MINIO_ROOT') else '/minio'
         for field in fields:
-            _field = field.json(entity=entity, code=self.code, db='orm', minio=_minio)
+            _field = field.json(entity=entity, code=self.code, db='orm')
             align, tool, width, domain = _field['align'], _field['tool'], _field['column_width'], _field['domain']
             _field['align'] = align if align else meta_field_tool_mapping.get(tool, 'left')
             _field['column_width'] = width if width else column_width(domain, tool)
 
             _fields[field.prop] = _field
 
-        _minio = settings.MINIO_ROOT if hasattr(settings, 'MINIO_ROOT') else '/minio'
         _view.update({
-            '$minio': _minio,
             '$db': 'orm',
             '$entity': entity,
             '$code': self.code,
@@ -87,17 +82,6 @@ class ValarMeta:
         view_item.update({
             "name": self.code.upper(),
             "saved": True,
-            "property": {
-                "value": "id",
-                "label": "name",
-                "display": "id",
-                "sort": "sort",
-                "disabled": "disabled",
-                "isLeaf": "isLeaf",
-                "icon": "icon",
-                "children": "children",
-                "pid": "pid",
-            }
         })
         values = always_merger.merge(default_values, code_values)
         view_item.update(values)
