@@ -1,7 +1,6 @@
 import datetime
 import json
 
-from django.conf import settings
 from django.core.paginator import Paginator
 from django.db.models.options import Options
 
@@ -15,7 +14,6 @@ from django.db.models.fields.files import FieldFile
 from django.forms import FileField
 
 from ..dao.orm_field import OrmField
-from ..models.auth import Account
 from ..models.core import VTree, VModel
 from ..models.meta import MetaField
 
@@ -52,7 +50,6 @@ class OrmDao(AbstractDao):
         return list(query_set.values(*props))
 
     def insert_one(self, item):
-        print(item)
         return self.__save__(item)
 
     def update_one(self, item):
@@ -332,7 +329,6 @@ def __set_simple_values__(fields, values):
         elif domain == 'JSONField':
             json_props.append(prop)
     for row in values:
-        row['$minio'] = settings.MINIO_ROOT
         for prop, formating in date_props_mapping.items():
             if row.get(prop):
                 row[prop] = row[prop].strftime(formating)
