@@ -1,7 +1,6 @@
 import json
 
 from django.apps import AppConfig
-from django.conf import settings
 from django.db import models
 from django.db.models import ManyToOneRel, OneToOneRel, ManyToManyRel, ManyToManyField, UUIDField, FileField, \
     ForeignKey, OneToOneField, DateField, TimeField, DateTimeField, BigAutoField, JSONField
@@ -76,7 +75,6 @@ class VModel(models.Model):
                 _set = getattr(self, accessor).all().order_by('-sort')
                 data[prop] = [item.id for item in _set]
                 data[f'{prop}_set'] = [item.json() for item in _set]
-        data['$minio'] = settings.MINIO_ROOT
         return data
 
 
