@@ -5,6 +5,9 @@ from django.urls import path, re_path
 urlpatterns = [
     path('socket/<str:handler>', handel_channel),
     path('batch', rest.batch),
+
+    path('<str:db>/<str:entity>/save_many', rest.save_many),
+    path('<str:db>/<str:entity>/delete_many', rest.delete_many),
     path('<str:db>/<str:entity>/save_one', rest.save_one),
     path('<str:db>/<str:entity>/insert_one', rest.insert_one),
     path('<str:db>/<str:entity>/delete_one', rest.delete_one),
@@ -20,7 +23,7 @@ urlpatterns = [
     path('load_customs', meta.load_customs),
     path('get_fields', meta.get_fields),
     path('save_custom', meta.save_custom),
-    path('upload_mapping', meta.upload_mapping),
+    path('upload_frame', meta.upload_frame),
 
     path('<str:db>/<str:entity>/save_file', file.save_file),
     path('<str:db>/<str:entity>/remove_file', file.remove_file),
