@@ -14,24 +14,23 @@ from ..models.auth import Account, AbstractUser, Menu
 
 def sign_in(request):
     body = json.loads(request.body)
-    username = body.get("username")
-    email = body.get("email")
-    password = body.get("password")
-    signin = body.get("signin")
+    keys = ['username', 'email', 'password', 'signin']
+    username, email, password, signin = [body.get(k) for k in keys]
     dao = Dao('valar.Account')
     account = dao.search({"username": username}).first()
+
     if account is not None:
         if signin:
             if not account.is_auth(password):
-                return ValarResponse(False, '密码错误', 'warning', status=400)
+                return ValarResponse(False, '密码错误', 'warning')
         else:
-            return ValarResponse(False, f"{username}已被占用", 'warning', status=400)
+            return ValarResponse(False, f"{username}已被占用", 'warning')
     else:
         if signin:
-            return ValarResponse(False, f"{username}不存在", 'warning', status=400)
+            return ValarResponse(False, f"{username}不存在", 'warning')
         else:
             if username == 'admin' and password != settings.SECRET_KEY:
-                return ValarResponse(False, "请输入正确的admin密码", 'warning', status=400)
+                return ValarResponse(False, "请输入正确的admin密码", 'warning')
             else:
                 account = dao.save_one({
                     "username": username,
