@@ -8,6 +8,7 @@ from ..channels.executer import execute_channel
 from ..channels.sender import ValarChannelSender
 from ..classes.valar_response import ValarResponse
 from ..dao import Dao
+from ..dao.engine import ValarEngine
 
 
 async def batch(request):
@@ -16,10 +17,30 @@ async def batch(request):
     return ValarResponse(True)
 
 
+def save_many(request, db, entity):
+    array = json.loads(request.body)
+    dao = Dao(entity, db)
+    keys = []
+    for item in array:
+        item.update({'saved': True})
+        bean = dao.save_one(item)
+        keys.append(bean.id)
+    return ValarResponse(keys)
+
+
+def delete_many(request, db, entity):
+    conditions = json.loads(request.body)
+    dao = Dao(entity, db)
+    paths = dao.delete(conditions)
+    minio = ValarEngine().get_minio_bucket(entity)
+    for path in paths:
+        minio.remove(path)
+    return ValarResponse(True)
+
+
 def insert_one(request, db, entity):
     item = json.loads(request.body)
     dao = Dao(entity, db)
-    print(item)
     bean = dao.insert_one(item)
     item = dao.serialize(bean)
     return ValarResponse(item)
@@ -56,7 +77,6 @@ def find_one(request, db, entity):
     dao = Dao(entity, db)
     bean = dao.find_one(_id)
     item = dao.serialize(bean)
-    item['$minio'] = settings.MINIO_ROOT
     return ValarResponse(item)
 
 
